# Установка

## Стандартная установка

Установка библиотеки выполняется с помощью pip:

```bash
pip install avito-api
```

Эта команда установит базовую версию библиотеки со всеми необходимыми зависимостями.

## Установка с поддержкой логирования

Если вы хотите использовать расширенное логирование с помощью библиотеки loguru, установите библиотеку с опциональной зависимостью:

```bash
pip install avito-api[log]
```

## Установка для разработчиков

Если вы хотите внести свой вклад в разработку библиотеки или запустить тесты, установите зависимости для разработки:

```bash
# Клонируем репозиторий
git clone https://github.com/yourusername/avito-api.git
cd avito-api

# Устанавливаем библиотеку и зависимости для разработки
pip install -e ".[dev]"
```

Это установит библиотеку в режиме разработки с дополнительными инструментами:

- pytest - для тестирования
- black, isort, flake8 - для форматирования и проверки кода
- mypy - для статической типизации
- и другие инструменты для разработки

## Требования

- Python 3.10 или выше
- requests - для синхронных HTTP-запросов
- httpx - для асинхронных HTTP-запросов
- pydantic - для валидации данных и сериализации
- loguru (опционально) - для расширенного логирования

## Проверка установки

После установки библиотеки вы можете проверить её работоспособность, выполнив следующий код:

```python
import avito_api
print(f"Версия avito_api: {avito_api.__version__}")

from avito_api.auth import SyncAuthClient
from avito_api.messenger import SyncMessengerClient

print("Импорт основных классов выполнен успешно!")
```

Если код выполняется без ошибок, значит библиотека установлена корректно.
